@@ -158,7 +158,7 @@ namespace Projections
                 gm.W(5000000.0,5000000.0,5000000.0,out x,out y,out z);
                 NormalGravity ng = new NormalGravity(NormalGravity.StandardModels.GRS80);
                 ng = new NormalGravity( NormalGravity.StandardModels.WGS84);
-                ng = new NormalGravity(6378137.0,3.986005e+14,7.292115147e-5,-1.0,1.08263e-3);
+                ng = new NormalGravity(6378137.0,3.986005e+14,7.292115147e-5,1.08263e-3, false);
                 ng = gm.ReferenceEllipsoid();
                 ng.DynamicalFormFactor(1);
                 Geocentric geo = ng.Earth();
