@@ -9,7 +9,7 @@ int main(array<System::String ^> ^/*args*/)
             k1 = 1,                                   // scale
             lon0 = -77 - 45/60.0;                     // Central meridian
         // Set up basic projection
-        AlbersEqualArea^ albers = gcnew AlbersEqualArea( Constants::WGS84::MajorRadius,
+        AlbersEqualArea^ albers = gcnew AlbersEqualArea( Constants::WGS84::EquatorialRadius,
                                                          Constants::WGS84::Flattening,
                                                          lat1, lat2, k1);
         {
