@@ -2,7 +2,7 @@
  * \file AlbersEqualArea.hpp
  * \brief Header for GeographicLib::AlbersEqualArea class
  *
- * Copyright (c) Charles Karney (2010-2020) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2010-2021) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -74,13 +74,8 @@ namespace GeographicLib {
     // atan (sqrt(-e2) * x)/sqrt(-e2) if f < 0
     // x                              if f = 0
     real atanhee(real x) const {
-      using std::atan2; using std::abs; using std::atanh;
-      return _f > 0 ? atanh(_e * x)/_e :
-        // We only invoke atanhee in txif for positive latitude.  Then x is
-        // only negative for very prolate ellipsoids (_b/_a >= sqrt(2)) and we
-        // still need to return a positive result in this case; hence the need
-        // for the call to atan2.
-        (_f < 0 ? (atan2(_e * abs(x), real(x < 0 ? -1 : 1))/_e) : x);
+      using std::atan; using std::abs; using std::atanh;
+      return _f > 0 ? atanh(_e * x)/_e : (_f < 0 ? (atan(_e * x)/_e) : x);
     }
     // return atanh(sqrt(x))/sqrt(x) - 1, accurate for small x
     static real atanhxm1(real x);
@@ -108,13 +103,18 @@ namespace GeographicLib {
       return t > 0 ? (x + y) * Math::sq( (sx * sy)/t ) / (sx + sy) :
         (x - y != 0 ? (sx - sy) / (x - y) : 1);
     }
-    // Datanhee(x,y) = atanhee((x-y)/(1-e^2*x*y))/(x-y)
+    // Datanhee(x,y) = (atanee(x)-atanee(y))/(x-y)
+    //               = atanhee((x-y)/(1-e^2*x*y))/(x-y)
     real Datanhee(real x, real y) const {
-      real t = x - y, d = 1 - _e2 * x * y;
-      return t != 0 ? atanhee(t / d) / t : 1 / d;
+      real t = x - y,  d = 1 - _e2 * x * y;
+      return t == 0 ? 1 / d :
+        (x*y < 0 ? atanhee(x) - atanhee(y) : atanhee(t / d)) / t;
     }
     // DDatanhee(x,y) = (Datanhee(1,y) - Datanhee(1,x))/(y-x)
     real DDatanhee(real x, real y) const;
+    real DDatanhee0(real x, real y) const;
+    real DDatanhee1(real x, real y) const;
+    real DDatanhee2(real x, real y) const;
     void Init(real sphi1, real cphi1, real sphi2, real cphi2, real k1);
     real txif(real tphi) const;
     real tphif(real txi) const;
