@@ -5,7 +5,7 @@
  * See the documentation for the C++ class.  The conversion is a literal
  * conversion from C++.
  *
- * Copyright (c) Charles Karney (2011-2019) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2011-2020) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  */
@@ -32,6 +32,7 @@ GeographicLib.DMS = {};
    *     - SECOND.
    */
   d) {
+  "use strict";
 
   var lookup, zerofill, internalDecode, numMatch,
       hemispheres_ = "SNWE",
@@ -73,20 +74,52 @@ GeographicLib.DMS = {};
         v = 0, i = 0, mi, pi, vals,
         ind1 = d.NONE, ind2, p, pa, pb;
     dmsa = dmsa
-      .replace(/\u2212/g, '-')  // U+2212 minus sign
-      .replace(/\u00b0/g, 'd')  // U+00b0 degree symbol
-      .replace(/\u00ba/g, 'd')  // U+00ba alt symbol
-      .replace(/\u2070/g, 'd')  // U+2070 sup zero
-      .replace(/\u02da/g, 'd')  // U+02da ring above
+      .replace(/\u00b0/g, 'd' ) // U+00b0 degree symbol
+      .replace(/\u00ba/g, 'd' ) // U+00ba alt symbol
+      .replace(/\u2070/g, 'd' ) // U+2070 sup zero
+      .replace(/\u02da/g, 'd' ) // U+02da ring above
+      .replace(/\u2218/g, 'd' ) // U+2218 compose function
+      .replace(/\*/g    , 'd' ) // GRiD symbol for degree
+
+      .replace(/`/g     , 'd' ) // grave accent
       .replace(/\u2032/g, '\'') // U+2032 prime
+      .replace(/\u2035/g, '\'') // U+2035 back prime
       .replace(/\u00b4/g, '\'') // U+00b4 acute accent
+      .replace(/\u2018/g, '\'') // U+2018 left single quote
       .replace(/\u2019/g, '\'') // U+2019 right single quote
-      .replace(/\u2033/g, '"')  // U+2033 double prime
-      .replace(/\u201d/g, '"')  // U+201d right double quote
-      .replace(/\u00a0/g, '')   // U+00a0 non-breaking space
-      .replace(/\u202f/g, '')   // U+202f narrow space
-      .replace(/\u2007/g, '')   // U+2007 figure space
-      .replace(/''/g, '"')      // '' -> "
+      .replace(/\u201b/g, '\'') // U+201b reversed-9 single quote
+      .replace(/\u02b9/g, '\'') // U+02b9 modifier letter prime
+      .replace(/\u02ca/g, '\'') // U+02ca modifier letter acute accent
+      .replace(/\u02cb/g, '\'') // U+02cb modifier letter grave accent
+
+      .replace(/\u2033/g, '"' ) // U+2033 double prime
+      .replace(/\u2036/g, '"' ) // U+2036 reversed double prime
+      .replace(/\u02dd/g, '"' ) // U+02dd double acute accent
+      .replace(/\u201c/g, '"' ) // U+201d left double quote
+      .replace(/\u201d/g, '"' ) // U+201d right double quote
+      .replace(/\u201f/g, '"' ) // U+201f reversed-9 double quote
+      .replace(/\u02ba/g, '"' ) // U+02ba modifier letter double prime
+
+      .replace(/\u2795/g, '+' ) // U+2795 heavy plus
+      .replace(/\u2064/g, '+' ) // U+2064 invisible plus
+
+      .replace(/\u2010/g, '-' ) // U+2010 dash
+      .replace(/\u2011/g, '-' ) // U+2011 non-breaking hyphen
+      .replace(/\u2013/g, '-' ) // U+2013 en dash
+      .replace(/\u2014/g, '-' ) // U+2014 em dash
+      .replace(/\u2212/g, '-' ) // U+2212 minus sign
+      .replace(/\u2796/g, '-' ) // U+2796 heavy minus
+
+      .replace(/\u00a0/g, ''  ) // U+00a0 non-breaking space
+      .replace(/\u2007/g, ''  ) // U+2007 figure space
+      .replace(/\u2009/g, ''  ) // U+2009 thin space
+      .replace(/\u200a/g, ''  ) // U+200a hair space
+      .replace(/\u200b/g, ''  ) // U+200b invisible space
+      .replace(/\u202f/g, ''  ) // U+202f narrow space
+      .replace(/\u2063/g, ''  ) // U+2063 invisible separator
+
+      .replace(/''/g,     '"' ) // '' -> "
+
       .trim();
 
     end = dmsa.length;
