@@ -4,7 +4,6 @@ function x = AngNormalize(x)
 %   x = ANGNORMALIZE(x) reduces angles to the range (-180, 180].  x can be
 %   any shape.
 
-  x = rem(x, 360);
-  x(x >   180) = x(x >   180) - 360;
-  x(x <= -180) = x(x <= -180) + 360;
+  x = remx(x, 360);
+  x(x == -180) = 180;
 end
