@@ -2,7 +2,7 @@
  * \file GeoCoords.cpp
  * \brief Implementation for GeographicLib::GeoCoords class
  *
- * Copyright (c) Charles Karney (2008-2017) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2008-2020) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -60,17 +60,18 @@ namespace GeographicLib {
   }
 
   string GeoCoords::GeoRepresentation(int prec, bool longfirst) const {
+    using std::isnan;           // Needed for Centos 7, ubuntu 14
     prec = max(0, min(9 + Math::extra_digits(), prec) + 5);
     ostringstream os;
     os << fixed << setprecision(prec);
     real a = longfirst ? _long : _lat;
     real b = longfirst ? _lat : _long;
-    if (!Math::isnan(a))
+    if (!isnan(a))
       os << a;
     else
       os << "nan";
     os << " ";
-    if (!Math::isnan(b))
+    if (!isnan(b))
       os << b;
     else
       os << "nan";
@@ -105,19 +106,19 @@ namespace GeographicLib {
 
   void GeoCoords::UTMUPSString(int zone, bool northp,
                                real easting, real northing, int prec,
-                               bool abbrev, std::string& utm) {
+                               bool abbrev, string& utm) {
     ostringstream os;
     prec = max(-5, min(9 + Math::extra_digits(), prec));
     // Need extra real because, since C++11, pow(float, int) returns double
     real scale = prec < 0 ? real(pow(real(10), -prec)) : real(1);
     os << UTMUPS::EncodeZone(zone, northp, abbrev) << fixed << setfill('0');
-    if (Math::isfinite(easting)) {
+    if (isfinite(easting)) {
       os << " " << Utility::str(easting / scale, max(0, prec));
       if (prec < 0 && abs(easting / scale) > real(0.5))
         os << setw(-prec) << 0;
     } else
       os << " nan";
-    if (Math::isfinite(northing)) {
+    if (isfinite(northing)) {
       os << " " << Utility::str(northing / scale, max(0, prec));
       if (prec < 0 && abs(northing / scale) > real(0.5))
         os << setw(-prec) << 0;
@@ -162,8 +163,9 @@ namespace GeographicLib {
   }
 
   void GeoCoords::FixHemisphere() {
+    using std::isnan;           // Needed for Centos 7, ubuntu 14
     if (_lat == 0 || (_northp && _lat >= 0) || (!_northp && _lat < 0) ||
-        Math::isnan(_lat))
+        isnan(_lat))
       // Allow either hemisphere for equator
       return;
     if (_zone != UTMUPS::UPS) {
