@@ -2,7 +2,7 @@
  * \file Math.cpp
  * \brief Implementation for GeographicLib::Math class
  *
- * Copyright (c) Charles Karney (2015-2020) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2015-2021) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -127,7 +127,7 @@ namespace GeographicLib {
     // In order to minimize round-off errors, this function exactly reduces
     // the argument to the range [-45, 45] before converting it to radians.
     using std::remquo;
-    T r; int q;
+    T r; int q = 0;
     // N.B. the implementation of remquo in glibc pre 2.22 were buggy.  See
     // https://sourceware.org/bugzilla/show_bug.cgi?id=17569
     // This was fixed in version 2.22 on 2015-08-05
@@ -135,15 +135,6 @@ namespace GeographicLib {
     r *= degree<T>();
     // g++ -O turns these two function calls into a call to sincos
     T s = sin(r), c = cos(r);
-#if defined(_MSC_VER) && _MSC_VER < 1900
-    // Before version 14 (2015), Visual Studio had problems dealing
-    // with -0.0.  Specifically
-    //   VC 10,11,12 and 32-bit compile: fmod(-0.0, 360.0) -> +0.0
-    //   VC 12       and 64-bit compile:  sin(-0.0)        -> +0.0
-    // AngNormalize has a similar fix.
-    // python 2.7 on Windows 32-bit machines has the same problem.
-    if (x == 0) s = x;
-#endif
     switch (unsigned(q) & 3U) {
     case 0U: sinx =  s; cosx =  c; break;
     case 1U: sinx =  c; cosx = -s; break;
@@ -157,7 +148,7 @@ namespace GeographicLib {
   template<typename T> T Math::sind(T x) {
     // See sincosd
     using std::remquo;
-    T r; int q;
+    T r; int q = 0;
     r = remquo(x, T(90), &q); // now abs(r) <= 45
     r *= degree<T>();
     unsigned p = unsigned(q);
@@ -170,7 +161,7 @@ namespace GeographicLib {
   template<typename T> T Math::cosd(T x) {
     // See sincosd
     using std::remquo;
-    T r; int q;
+    T r; int q = 0;
     r = remquo(x, T(90), &q); // now abs(r) <= 45
     r *= degree<T>();
     unsigned p = unsigned(q + 1);
@@ -206,6 +197,7 @@ namespace GeographicLib {
     case 1: ang = (y >= 0 ? 180 : -180) - ang; break;
     case 2: ang =  90 - ang; break;
     case 3: ang = -90 + ang; break;
+    default: break;
     }
     return ang;
   }
